@@ -5,9 +5,8 @@
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation; either version 3 of the License, or (at your option) any
- * later version. See http://www.gnu.org/copyleft/lgpl.html the full text of the
- * license.
+ * Software Foundation; either version 2 or version 3 of the License.
+ * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
  */
 
 
@@ -111,4 +110,8 @@ void PowerInterface::restart()
     d->consoleKitInterface->call("Restart");
 }
 
-#include "power_moc.cpp"
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+#include "power_moc5.cpp"
+#else
+#include "power_moc4.cpp"
+#endif
