@@ -19,7 +19,6 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/stat.h>
-#include <sys/mman.h>
 
 #include "configuration.h"
 #include "display-manager.h"
@@ -140,29 +139,11 @@ signal_cb (Process *process, int signum)
     // FIXME: Stop XDMCP server
 }
 
-static gboolean
-exit_cb (gpointer data)
-{
-    /* Clean up display manager */
-    g_object_unref (display_manager);
-    display_manager = NULL;
-
-    /* Remove D-Bus interface */
-    g_bus_unown_name (bus_id);
-    if (seat_bus_entries)
-        g_hash_table_unref (seat_bus_entries);
-    if (session_bus_entries)
-        g_hash_table_unref (session_bus_entries);
-
-    g_debug ("Exiting with return value %d", exit_code);
-    exit (exit_code);
-}
-
 static void
 display_manager_stopped_cb (DisplayManager *display_manager)
 {
     g_debug ("Stopping daemon");
-    g_idle_add (exit_cb, NULL);
+    g_main_loop_quit (loop);
 }
 
 static GVariant *
@@ -870,7 +851,9 @@ main (int argc, char **argv)
     if (argc >= 2 && strcmp (argv[1], "--session-child") == 0)
         return session_child_run (argc, argv);
 
+#if !defined(GLIB_VERSION_2_36)
     g_type_init ();
+#endif
     loop = g_main_loop_new (NULL, FALSE);
 
     g_signal_connect (process_get_current (), "got-signal", G_CALLBACK (signal_cb), NULL);
@@ -1079,12 +1062,6 @@ main (int argc, char **argv)
                              NULL,
                              NULL);
 
-    if (config_get_boolean (config_get_instance (), "LightDM", "lock-memory"))
-    {
-        /* Protect memory from being paged to disk, as we deal with passwords */
-        mlockall (MCL_CURRENT | MCL_FUTURE);
-    }
-
     if (getuid () != 0)
         g_debug ("Running in user mode");
     if (getenv ("DISPLAY"))
@@ -1227,5 +1204,17 @@ main (int argc, char **argv)
 
     g_main_loop_run (loop);
 
-    return EXIT_SUCCESS;
+    /* Clean up display manager */
+    g_object_unref (display_manager);
+    display_manager = NULL;
+
+    /* Remove D-Bus interface */
+    g_bus_unown_name (bus_id);
+    if (seat_bus_entries)
+        g_hash_table_unref (seat_bus_entries);
+    if (session_bus_entries)
+        g_hash_table_unref (session_bus_entries);
+
+    g_debug ("Exiting with return value %d", exit_code);
+    return exit_code;
 }
