@@ -9,11 +9,6 @@
 
 static GKeyFile *config;
 
-static void
-request_cb (const gchar *message)
-{
-}
-
 int
 main (int argc, char **argv)
 {
@@ -28,9 +23,11 @@ main (int argc, char **argv)
     gchar buffer[1024];
     gssize n_read, n_sent;
 
+#if !defined(GLIB_VERSION_2_36)
     g_type_init ();
+#endif
 
-    status_connect (request_cb);
+    status_connect (NULL);
 
     status_notify ("VNC-CLIENT START");
 
